@@ -74,10 +74,12 @@ class Bar(ChartPart):
         )
 
         xAxis = spec["xAxis"]
+        xAxis["name"] = x
         xAxis["type"] = "category"
         xAxis["data"] = data.index.tolist()
 
         spec["yAxis.type"] = "value"
+        spec["yAxis.name"] = y
 
         series = [
             {
@@ -129,10 +131,12 @@ class Line(ChartPart):
         data, x, y, color = mapping.transform(data, x, y, color)
 
         xAxis = spec["xAxis"]
+        xAxis["name"] = x
         xAxis["type"] = "category"
         xAxis["data"] = data.index.tolist()
 
         spec["yAxis.type"] = "value"
+        spec["yAxis.name"] = y
 
         series = [
             {
